netapp_ontap.models.zapp_s3_bucket_application_components_access_policies_conditions API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.zapp_s3_bucket_application_components_access_policies_conditions`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ZappS3BucketApplicationComponentsAccessPoliciesConditionsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ZappS3BucketApplicationComponentsAccessPoliciesConditions object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `delimiters: List[str] GET POST PATCH`

    The delimiters field of the zapp_s3_bucket_application_components_access_policies_conditions.

  `max_keys: List[Size] GET POST PATCH`

    The max_keys field of the zapp_s3_bucket_application_components_access_policies_conditions.

  `operator: str GET POST`

    Policy Condition Operator.

  `prefixes: List[str] GET POST PATCH`

    The prefixes field of the zapp_s3_bucket_application_components_access_policies_conditions.

  `source_ips: List[str] GET POST PATCH`

    The source_ips field of the zapp_s3_bucket_application_components_access_policies_conditions.

  `usernames: List[str] GET POST PATCH`

    The usernames field of the zapp_s3_bucket_application_components_access_policies_conditions.